@@ -1,27 +1,16 @@
 module Main where
 
 import Language.Haskell.HsColour
+import qualified Language.Haskell.HsColour as HSColour
 import Language.Haskell.HsColour.Colourise (readColourPrefs)
-
+import Language.Haskell.HsColour.Options
 import System
 import IO (hPutStrLn,hFlush,stdout,stderr,hSetBuffering,BufferMode(..))
 import Monad (when)
 import List  (intersperse)
+import Debug.Trace
 
-version = "1.10.1"
-
--- | Command-line options
-data Option =
-    Help		-- ^ print usage message
-  | Version		-- ^ report version
-  | Information		-- ^ report auxiliary information, e.g. CSS defaults
-  | Format Output	-- ^ what type of output to produce
-  | LHS Bool		-- ^ literate input (i.e. multiple embedded fragments)
-  | Anchors Bool	-- ^ whether to add anchors
-  | Partial Bool	-- ^ whether to produce a full document or partial
-  | Input FilePath	-- ^ input source file
-  | Output FilePath	-- ^ output source file
-  deriving Eq
+version = "1.13"
 
 optionTable :: [(String,Option)]
 optionTable = [ ("help",    Help)
@@ -29,11 +18,13 @@ optionTable = [ ("help",    Help)
               , ("print-css", Information)
               , ("html",   Format HTML)
               , ("css",    Format CSS)
+              , ("icss",   Format ICSS)
               , ("tty",    Format TTY)
               , ("latex",  Format LaTeX)
               , ("mirc",   Format MIRC)
-              , ("lit",       LHS True)
-              , ("nolit",     LHS False)
+              , ("lit",    LHS Bird)
+              , ("lit-tex",LHS TeX)
+              , ("nolit",  LHS NoLit)
               , ("anchor",    Anchors True)
               , ("noanchor",  Anchors False)
               , ("partial",   Partial True)
@@ -58,11 +49,11 @@ main = do
       outFile = [ f | Output f <- good ]
       fileInteract = fileInteractOut outFile
       output    = useDefault TTY         id           formats
-      ioWrapper = useDefault ttyInteract fileInteract [ f | Input f <- good ]
+      ioWrapper = useDefault ttyInteract fileInteract [ f | Input f   <- good ]
       anchors   = useDefault False       id           [ b | Anchors b <- good ]
       partial   = useDefault False       id           [ b | Partial b <- good ]
-      lhs       = useDefault False       id           [ b | LHS b <- good ] 
-      title     = useDefault "Haskell code" id        [ f | Input f <- good ]
+      lhs       = useDefault NoLit       id           [ b | LHS b     <- good ] 
+      title     = useDefault "Haskell code" id        [ f | Input f   <- good ]
   when (not (null bad))
        (errorOut ("Unrecognised option(s): "++unwords bad++"\n"++usage prog))
   when (Help `elem` good)    (do putStrLn (usage prog); exitSuccess)
@@ -74,7 +65,7 @@ main = do
                   ++unwords (map show formats)))
   when (length outFile > 1)
        (errorOut ("Can only have one output file at a time."))
-  ioWrapper (hscolour output pref anchors partial lhs title)
+  ioWrapper (HSColour.hscolour output pref anchors partial lhs title)
   hFlush stdout
 
   where
@@ -103,9 +94,10 @@ indent n (c:s)    = c: indent n s
 
 -- Rather than have a separate .css file, define some reasonable defaults here.
 cssDefaults = "\
-\.keyglyph, .layout {color: red;}\n\
-\.keyword {color: blue;}\n\
-\.comment, .comment a {color: green;}\n\
-\.str, .chr {color: teal;}\n\
-\.keyword,.conid, .varid, .conop, .varop, .num, .cpp, .sel, .definition {}\n\
+\.hs-keyglyph, .hs-layout {color: red;}\n\
+\.hs-keyword {color: blue;}\n\
+\.hs-comment, .hs-comment a {color: green;}\n\
+\.hs-str, .hs-chr {color: teal;}\n\
+\.hs-keyword, .hs-conid, .hs-varid, .hs-conop, .hs-varop, .hs-num, \
+\.hs-cpp, .hs-sel, .hs-definition {}\n\
 \"
